@@ -1120,7 +1120,7 @@ create_prefs (void)
     GLADE_HOOKUP_OBJECT (prefs, cddbServerName, "cddb_server_name");
     
     tooltips = gtk_tooltips_new ();
-    gtk_tooltips_set_tip (tooltips, cddbServerName, _("The CDDB server to get disc info from (default is freedb.freedb.org)"), NULL);
+    gtk_tooltips_set_tip (tooltips, cddbServerName, _("The CDDB server to get disc info from (default is gnudb.gnudb.org)"), NULL);
     
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_widget_show (hbox);
@@ -1549,7 +1549,7 @@ toggle_allow_tracknum(void)
 }
 
 const char* 
-GBLprogramName = "Asunder 2.9.6";
+GBLprogramName = "Asunder 2.9.7";
 
 static const char* 
 GBLauthors[2] = {
@@ -1652,6 +1652,9 @@ GBLauthors[2] = {
 "Kevin \"Eonfge\" Degeling\n"
 "- Flatpak/Flathub setup for Asunder, version 2.9.6\n"
 "\n"
+"Przemyslaw Buczkowski\n"
+"- Fixed the CDDB tooltip after switch to Gnudb.\n"
+"\n"
 "Toni Graffy\n"
 "Maintainer of many SuSE packages at PackMan\n"
 "- SuSE packages of Asunder, versions 0.1 - 1.6\n"
@@ -1787,6 +1790,9 @@ GBLtranslators =
 "Clement Raievsky\n"
 "- fr (French) translation of Asunder versions 2.1 - 2.2\n"
 "\n"
+"Jacques Burel\n"
+"- fr (French) translation of Asunder version 2.9.7\n"
+"\n"
 "Miguel Anxo Bouzada\n"
 "- gl (Galician) translation of Asunder version 2.2\n"
 "\n"
@@ -1803,7 +1809,7 @@ GBLtranslators =
 "- hu (Hungarian) translation of Asunder versions 1.9.2 - 2.3\n"
 "\n"
 "Valerio Guaglianone\n"
-"- it (Italian) translation of Asunder versions 0.8 - 0.8.1, 1.6 - 1.9\n"
+"- it (Italian) translation of Asunder versions 0.8 - 0.8.1, 1.6 - 2.9.7\n"
 "\n"
 "Fabio Vergnani\n"
 "- it (Italian) translation of Asunder version 1.0\n"
