@@ -71,6 +71,7 @@ static gboolean start_refresh_thread(gpointer data);
 extern const char* GBLprogramName;
 
 int gbl_null_fd;
+JoinState join_artist_title = JOIN_UNSET;
 
 int main(int argc, char *argv[])
 {
@@ -162,10 +163,20 @@ int main(int argc, char *argv[])
     col = gtk_tree_view_get_column(GTK_TREE_VIEW(tracklist), COL_TRACKTITLE);
     gtk_tree_view_column_set_resizable(col, TRUE);
 
+    // Set up initially hidden column to hold artist + title if the user opts to
+    // join the two fields together
+    renderer = gtk_cell_renderer_text_new();
+    gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(tracklist), -1, 
+                    _("Title"), renderer, "text", COL_TRACKARTISTTITLE, NULL);
+
+    GtkTreeViewColumn * concatenatedTitleCol = gtk_tree_view_get_column(
+            GTK_TREE_VIEW(tracklist), COL_TRACKARTISTTITLE);
+    gtk_tree_view_column_set_visible(concatenatedTitleCol, FALSE);
+
     renderer = gtk_cell_renderer_text_new();
     gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(tracklist), -1, 
                     _("Time"), renderer, "text", COL_TRACKTIME, NULL);
-    
+ 
     // set up the columns for the album selecting dropdown box
     renderer = gtk_cell_renderer_text_new();
     gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(pick_disc), renderer, TRUE);
@@ -374,7 +385,8 @@ GtkTreeModel * create_model_from_disc(cddb_disc_t * disc)
                                G_TYPE_UINT, /* track number, visual */
                                G_TYPE_STRING, /* track artist */
                                G_TYPE_STRING, /* track title */
-                               G_TYPE_STRING  /* track time */
+                               G_TYPE_STRING, /* track time */
+                               G_TYPE_STRING  /* artist + title concatenated */
                                );
     
     for (track = cddb_disc_get_track_first(disc); track != NULL; track = cddb_disc_get_track_next(disc))
@@ -397,6 +409,7 @@ GtkTreeModel * create_model_from_disc(cddb_disc_t * disc)
             COL_TRACKNUM_VIS, cddb_track_get_number(track) + global_prefs->first_track_num_offset,
             COL_TRACKARTIST, track_artist,
             COL_TRACKTITLE, track_title,
+            COL_TRACKARTISTTITLE, "",
             COL_TRACKTIME, time,
             -1);
     }
@@ -788,7 +801,16 @@ void update_tracklist(cddb_disc_t * disc)
     cddb_track_t * track;
     bool singleartist;
     char logStr[1024];
-    
+ 
+    // Reset column visibility to defaults
+    join_artist_title = JOIN_UNSET;
+    gtk_tree_view_column_set_visible(gtk_tree_view_get_column(GTK_TREE_VIEW(tracklist),
+                COL_TRACKARTISTTITLE),
+            FALSE);
+    gtk_tree_view_column_set_visible(gtk_tree_view_get_column(GTK_TREE_VIEW(tracklist),
+                COL_TRACKTITLE),
+            TRUE);
+
     gbl_current_discid = cddb_disc_get_discid(disc);
 
     snprintf(logStr, 1024, "update_tracklist() disk '%08x' '%s' '%s' '%s'\n",
