@@ -170,6 +170,9 @@ prefs * get_default_prefs()
     p->rip_fdkaac = 0;
     p->fdkaac_bitrate = 10;
     
+    p->concatenated_track_separator[0] = '/';
+    p->concatenated_track_separator[1] = '\0';
+
     return p;
 }
 
@@ -222,6 +225,9 @@ void set_widgets_from_prefs(prefs * p)
         //~ gtk_expander_set_expanded (GTK_EXPANDER(lookup_widget(win_prefs, "proprietary_formats_expander")), TRUE);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(win_prefs, "allow_tracknum")), p->allow_first_track_num_change);
     toggle_allow_tracknum(); // This will set up the rest of the related widgets
+
+    gtk_entry_set_text(GTK_ENTRY(lookup_widget(win_prefs,
+					"concatenated_track_separator")), p->concatenated_track_separator);
     
     /* disable widgets if needed */
     if ( !(p->rip_mp3) )
@@ -328,6 +334,10 @@ void get_prefs_from_widgets(prefs * p)
     p->cddb_port_number = atoi(gtk_entry_get_text(GTK_ENTRY(lookup_widget(win_prefs, "cddb_port_number"))));
     
     p->do_log = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget(win_prefs, "do_log")));
+
+    tocopyc = gtk_entry_get_text(GTK_ENTRY(lookup_widget(win_prefs,
+                    "concatenated_track_separator")));
+    p->concatenated_track_separator[0] = tocopyc[0];
     
     p->more_formats_expanded = gtk_expander_get_expanded (GTK_EXPANDER(lookup_widget(win_prefs, "more_formats_expander")));
     //~ p->proprietary_formats_expanded = gtk_expander_get_expanded (GTK_EXPANDER(lookup_widget(win_prefs, "proprietary_formats_expander")));
@@ -466,6 +476,7 @@ void save_prefs(prefs * p)
         fprintf(config, "%d\n", p->track_num_width);
         fprintf(config, "%d\n", p->rip_fdkaac);
         fprintf(config, "%d\n", p->fdkaac_bitrate);
+        fprintf(config, "%s\n", p->concatenated_track_separator);
         
         fclose(config);
     } else {
@@ -679,6 +690,12 @@ void load_prefs(prefs * p)
         // this one can be 0
         p->fdkaac_bitrate = read_line_num(fd);
         
+        aCharPtr = read_line(fd);
+        if (aCharPtr != NULL)
+        {
+            p->concatenated_track_separator[0] = aCharPtr[0];
+        }
+
         close(fd);
     } else {
         fprintf(stderr, "Warning: could not load config file: %s\n", strerror(errno));
