@@ -53,7 +53,7 @@ typedef struct _prefs
 } prefs;
 
 #define DEFAULT_PROXY_PORT 8080
-#define DEFAULT_CDDB_SERVER "freedb.freedb.org"
+#define DEFAULT_CDDB_SERVER "gnudb.gnudb.org"
 #define DEFAULT_CDDB_SERVER_PORT 8880
 
 extern prefs * global_prefs;
