@@ -394,6 +394,13 @@ gpointer rip(gpointer data)
     trim_chars(albumtitle_trimmed, BADCHARS);
     char * albumgenre_trimmed = strdup(albumgenre);
     trim_chars(albumgenre_trimmed, BADCHARS);
+
+    int titleColumn = COL_TRACKTITLE;
+    
+    if(single_artist && join_artist_title == JOIN_ON)
+    {
+        titleColumn = COL_TRACKARTISTTITLE;
+    }
     
     while(rowsleft)
     {
@@ -409,7 +416,7 @@ gpointer rip(gpointer data)
                 COL_TRACKNUM, &tracknum,
                 COL_TRACKNUM_VIS, &tracknum_vis,
                 COL_TRACKARTIST, &trackartist,
-                COL_TRACKTITLE, &tracktitle,
+                titleColumn, &tracktitle,
                 -1);
         gdk_threads_leave();
         
@@ -602,6 +609,12 @@ gpointer encode(gpointer data)
     trim_chars(album_title_trimmed, BADCHARS);
     album_genre_trimmed = strdup(album_genre);
     trim_chars(album_genre_trimmed, BADCHARS);
+ 
+    int titleColumn = COL_TRACKTITLE;
+    if(single_artist && join_artist_title == JOIN_ON)
+    {
+        titleColumn = COL_TRACKARTISTTITLE;
+    }
     
     while(rowsleft)
     {
@@ -646,7 +659,7 @@ gpointer encode(gpointer data)
                 COL_TRACKNUM, &tracknum,
                 COL_TRACKNUM_VIS, &tracknum_vis,
                 COL_TRACKARTIST, &trackartist,
-                COL_TRACKTITLE, &tracktitle,
+                titleColumn, &tracktitle,
                 COL_TRACKTIME, &tracktime,
                 -1);
         gdk_threads_leave();
